#include <stdexcept>
#include <iostream>

class HardwareDevice {
public:
    HardwareDevice(int intr=0) : interrupt(intr) {}
    void lowLevelOp() throw(std::runtime_error) { // ... something
        if(!interrupt)
            throw std::runtime_error("bad interrupt");
    }
    // other methods...
private:
    int interrupt;
};

class DeviceManager {
public:
    DeviceManager(int interrupt) : dvc(new HardwareDevice(interrupt)) {}
    ~DeviceManager() {
        delete dvc;
    }
    void use() { // ... something
        dvc->lowLevelOp();
    }
    // other methods...
private:
    HardwareDevice *const dvc;
};

void test(int interrupt) {
    DeviceManager* mgr = new DeviceManager(interrupt);
    // XXX it may throw an exception
    try {
        mgr->use();
    } catch(std::runtime_error& e) {
        std::cerr << e.what() << std::endl;
        delete mgr; // XXX or more simply just leave the delete at the end of the method
        mgr = nullptr;
    }
    // ...
    if(mgr)
        delete mgr;
}

int main() {
    test(3);
    test(0); // will throw
}